@@ -1,10 +1,7 @@
 cat("\nTests for 'PFDS (jmodelMult)'")
 
-myEps <- .Machine$double.eps
-# browser()
-cat(getwd())
+myEps <- if (capabilities("long.double")) .Machine$double.eps else 1e-9
 
-#load("JSM/data/aids.rda")
 fitLME <- lme(sqrt(CD4) ~ bs(obstime, 4, Boundary.knots = c(0, 21.5)), random =~ 1 | ID, data = aids)
 fitCOX <- coxph(Surv(start, stop, event) ~ drug, data = aids, x = TRUE)
 control <- list(max.iter = 50, nknot = 5, SE.method = 'PFDS', tol.L = 1e-08, tol.P = 1e-04)
@@ -26,5 +23,3 @@ test_that(" basic PLFD jmodelTM test with for aids data model = 2, rho = 1 ", {
   expect_equal( mean(m_TM$est.bi), -0.0007730147, tolerance = (10 ^ 4) * myEps, scale = 1)
   expect_equal( mean (m_TM$Vcov), 0.0006784183, tolerance = (10 ^ 5) * myEps, scale = 1)
 })
-
- 
